import { LatestPricesResponse, LatestCoinPricesResponse, LatestBuySellPriceResponse, OpenOrdersResponse, CompletedOrdersResponse } from './types';
export declare class CoinspotPublicApi {
    private BASE_URL;
    /**
     * Get latest prices for all coins
     * @returns {Promise<LatestPricesResponse>} Object containing latest prices for all coins
     */
    getLatestPrices(): Promise<LatestPricesResponse>;
    /**
     * Get latest price for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<LatestCoinPricesResponse>} Object containing latest price for the specified coin
     */
    getLatestCoinPrice(cointype: string): Promise<LatestCoinPricesResponse>;
    /**
     * Get latest price for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<LatestCoinPricesResponse>} Object containing latest price for the specified coin in the specified market
     */
    getLatestCoinMarketPrice(cointype: string, markettype: string): Promise<LatestCoinPricesResponse>;
    /**
     * Get latest buy price for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest buy price for the specified coin
     */
    getLatestBuyPrice(cointype: string): Promise<LatestBuySellPriceResponse>;
    /**
     * Get latest buy price for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest buy price for the specified coin in the specified market
     */
    getLatestBuyMarketPrice(cointype: string, markettype: string): Promise<LatestBuySellPriceResponse>;
    /**
     * Get latest sell price for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest sell price for the specified coin
     */
    getLatestSellPrice(cointype: string): Promise<LatestBuySellPriceResponse>;
    /**
     * Get latest sell price for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<LatestBuySellPriceResponse>} Object containing latest sell price for the specified coin in the specified market
     */
    getLatestSellMarketPrice(cointype: string, markettype: string): Promise<LatestBuySellPriceResponse>;
    /**
     * Get open orders for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<OpenOrdersResponse>} Object containing open buy and sell orders for the specified coin
     */
    getOpenOrders(cointype: string): Promise<OpenOrdersResponse>;
    /**
     * Get open orders for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<OpenOrdersResponse>} Object containing open buy and sell orders for the specified coin in the specified market
     */
    getOpenMarketOrders(cointype: string, markettype: string): Promise<OpenOrdersResponse>;
    /**
     * Get completed orders for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<CompletedOrdersResponse>} Object containing completed buy and sell orders for the specified coin
     */
    getCompletedOrders(cointype: string): Promise<CompletedOrdersResponse>;
    /**
     * Get completed orders for a specific coin in a specific market
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} markettype - Market coin short name (e.g., 'USDT')
     * @returns {Promise<CompletedOrdersResponse>} Object containing completed buy and sell orders for the specified coin in the specified market
     */
    getCompletedMarketOrders(cointype: string, markettype: string): Promise<CompletedOrdersResponse>;
}
//# sourceMappingURL=coinspotPublicApi.d.ts.map