import { ReadOnlyApiStatusResponse, MyCoinBalanceResponse, OpenOrdersResponse, CompletedOrdersResponse, MyCoinBalancesResponse, MyOpenMarketOrdersResponse, MyOpenLimitOrdersResponse, MyOrderHistoryResponse, MyAffiliatePaymentsResponse, MyDepositHistoryResponse, MyReferralPaymentsResponse, MySendReceiveHistoryResponse, MyWithdrawalHistoryResponse } from './types';
import { CoinspotApiBase } from './coinspotApiBase';
export declare class CoinspotReadOnlyApi extends CoinspotApiBase {
    /**
     * Check the status of the API
     * @returns {Promise<ReadOnlyApiStatusResponse>} Object containing API status
     */
    checkReadOnlyApiStatus(): Promise<ReadOnlyApiStatusResponse>;
    /**
     * Get open market orders
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
     * @returns {Promise<OpenOrdersResponse>} Object containing open market orders for the specified coin and market
     */
    getOpenMarketOrders(cointype: string, markettype?: string): Promise<OpenOrdersResponse>;
    /**
     * Get completed market orders
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
     * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format or UNIX EPOCH time
     * @param {string} [enddate] - End date in 'YYYY-MM-DD' format or UNIX EPOCH time
     * @param {number} [limit=200] - Number of records to return (max 500)
     * @returns {Promise<CompletedOrdersResponse>} Object containing completed market orders for the specified parameters
     */
    getCompletedMarketOrders(cointype: string, markettype?: string, startdate?: string, enddate?: string, limit?: number): Promise<CompletedOrdersResponse>;
    /**
    * Get user's coin balances
    * @returns {Promise<MyCoinBalancesResponse>} Object containing user's coin balances
    */
    getMyCoinBalances(): Promise<MyCoinBalancesResponse>;
    /**
    * Get user's coin balance (available)
    * @param {string} cointype - Coin short name (e.g., 'AUD', 'BTC', 'LTC', 'DOGE')
    * @param {string} available - Whether to return available balance ('yes' or 'no')
    * @returns {Promise<MyCoinBalanceResponse>} Object containing user's coin balance
    */
    getMyCoinBalance(cointype: string, available: string): Promise<MyCoinBalanceResponse>;
    /**
    * Get user's open market orders
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} [markettype] - Market coin short name (e.g., 'USDT', 'AUD')
    * @returns {Promise<MyOpenMarketOrdersResponse>} Object containing user's open market orders
    */
    getMyOpenMarketOrders(cointype?: string, markettype?: string): Promise<MyOpenMarketOrdersResponse>;
    /**
    * Get user's open limit orders
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @returns {Promise<MyOpenLimitOrdersResponse>} Object containing user's open limit orders
    */
    getMyOpenLimitOrders(cointype?: string): Promise<MyOpenLimitOrdersResponse>;
    /**
    * Get user's order history
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {number} [limit=200] - Number of records to return (max 500)
    * @returns {Promise<MyOrderHistoryResponse>} Object containing user's order history
    */
    getMyOrderHistory(cointype?: string, markettype?: string, startdate?: string, enddate?: string, limit?: number): Promise<MyOrderHistoryResponse>;
    /**
    * Get user's market order history
    * @param {string} [cointype] - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} [markettype] - Market coin short name (e.g., 'AUD', 'USDT')
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format or UNIX EPOCH time
    * @param {number} [limit=200] - Number of records to return (max 500)
    * @returns {Promise<MyOrderHistoryResponse>} Object containing user's market order history
    */
    getMyMarketOrderHistory(cointype?: string, markettype?: string, startdate?: string, enddate?: string, limit?: number): Promise<MyOrderHistoryResponse>;
    /**
    * Get user's send and receive history
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format
    * @returns {Promise<MySendReceiveHistoryResponse>} Object containing user's send and receive history
    */
    getMySendReceiveHistory(startdate?: string, enddate?: string): Promise<MySendReceiveHistoryResponse>;
    /**
    * Get user's deposit history
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format
    * @returns {Promise<MyDepositHistoryResponse>} Object containing user's deposit history
    */
    getMyDepositHistory(startdate?: string, enddate?: string): Promise<MyDepositHistoryResponse>;
    /**
    * Get user's withdrawal history
    * @param {string} [startdate] - Start date in 'YYYY-MM-DD' format
    * @param {string} [enddate] - End date in 'YYYY-MM-DD' format
    * @returns {Promise<MyWithdrawalHistoryResponse>} Object containing user's withdrawal history
    */
    getMyWithdrawalHistory(startdate?: string, enddate?: string): Promise<MyWithdrawalHistoryResponse>;
    /**
    * Get user's affiliate payments
    * @returns {Promise<MyAffiliatePaymentsResponse>} Object containing user's affiliate payments
    */
    getMyAffiliatePayments(): Promise<MyAffiliatePaymentsResponse>;
    /**
    * Get user's referral payments
    * @returns {Promise<MyReferralPaymentsResponse>} Object containing user's referral payments
    */
    getMyReferralPayments(): Promise<MyReferralPaymentsResponse>;
}
//# sourceMappingURL=coinspotReadOnlyApi.d.ts.map