"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCoinspotApi = exports.Coinspot = void 0;
// src/index.ts
const coinspotPublicApi_1 = require("./coinspotPublicApi");
const coinspotReadOnlyApi_1 = require("./coinspotReadOnlyApi");
const coinspotApi_1 = require("./coinspotApi");
__exportStar(require("./types"), exports);
class Coinspot {
    constructor(apiKey, apiSecret) {
        this.apiKeyRequiredMessage = 'API key and secret are required for authenticated operations';
        this.public = new coinspotPublicApi_1.CoinspotPublicApi();
        if (apiKey && apiSecret) {
            this.readOnly = new coinspotReadOnlyApi_1.CoinspotReadOnlyApi(apiKey, apiSecret);
            this.authenticated = new coinspotApi_1.CoinspotApi(apiKey, apiSecret);
        }
        else {
            this.readOnly = null;
            this.authenticated = null;
        }
    }
    // ========================================================================
    // Public API
    // ========================================================================
    async latestCoinPrice(coin) {
        return this.public.getLatestCoinPrice(coin);
    }
    async latestPrices() {
        return this.public.getLatestPrices();
    }
    async latestBuyPrice(coin) {
        return this.public.getLatestBuyPrice(coin);
    }
    async latestSellPrice(coin) {
        return this.public.getLatestSellPrice(coin);
    }
    async openOrderList(coin) {
        return this.public.getOpenOrders(coin);
    }
    async completedOrderList(coin) {
        return this.public.getCompletedOrders(coin);
    }
    // ========================================================================
    // Authenticated Read-Only API
    // ========================================================================
    async coinBalance(coin) {
        if (!this.readOnly) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.readOnly.getMyCoinBalance(coin, 'yes');
    }
    async balance() {
        if (!this.readOnly) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.readOnly.getMyCoinBalances();
    }
    async readOnlyApiStatus() {
        if (!this.readOnly) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.readOnly.checkReadOnlyApiStatus();
    }
    // ========================================================================
    // Authenticated API, operate on your accounts, buy, sell, etc.
    // ========================================================================
    async fullAccessApiStatus() {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.checkFullAccessApiStatus();
    }
    async coinDepositAddress(coin) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.getCoinDepositAddress(coin);
    }
    async marketBuyOrder(coin, amount, rate) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeMarketBuyOrder(coin, amount, rate);
    }
    async marketSellOrder(coin, amount, rate) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeMarketSellOrder(coin, amount, rate);
    }
    async cancelBuyOrder(id) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.cancelBuyOrder(id);
    }
    async cancelSellOrder(id) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.cancelSellOrder(id);
    }
    async buyNowOrder(coin, amounttype, amount, rate, threshold, direction) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeBuyNowOrder(coin, amounttype, amount, rate, threshold, direction);
    }
    async sellNowOrder(coin, amounttype, amount, rate, threshold, direction) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeSellNowOrder(coin, amounttype, amount, rate, threshold, direction);
    }
    async swapNow(cointypesell, cointypebuy, amount, rate, threshold, direction) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.placeSwapNowOrder(cointypesell, cointypebuy, amount, rate, threshold, direction);
    }
    async buyNowQuote(coin, amount, amounttype) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.getBuyNowQuote(coin, amount, amounttype);
    }
    async sellNowQuote(coin, amount, amounttype) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.getSellNowQuote(coin, amount, amounttype);
    }
    async swapNowQuote(sellcoin, buycoin, amount) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.getSwapNowQuote(sellcoin, buycoin, amount);
    }
    async withdrawalHistory(coin) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.getCoinWithdrawalDetails(coin);
    }
    async withdrawCoins(coin, amount, address, emailconfirm, network, paymentid) {
        if (!this.authenticated) {
            throw new Error(this.apiKeyRequiredMessage);
        }
        return this.authenticated.withdrawCoin(coin, amount, address, emailconfirm, network, paymentid);
    }
}
exports.Coinspot = Coinspot;
// Named export
const createCoinspotApi = (apiKey, apiSecret) => {
    return new Coinspot(apiKey, apiSecret);
};
exports.createCoinspotApi = createCoinspotApi;
// Default export
exports.default = Coinspot;
//# sourceMappingURL=index.js.map