"use strict";
// src/utils/logger.ts
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logApiCall = logApiCall;
const winston_1 = __importDefault(require("winston"));
const winston_2 = require("winston");
const node_fs_1 = __importDefault(require("node:fs"));
const node_path_1 = __importDefault(require("node:path"));
// Get the project root directory
const projectRoot = process.cwd();
// Ensure the logs directory exists in the project root
const logDir = node_path_1.default.join(projectRoot, 'logs');
if (!node_fs_1.default.existsSync(logDir)) {
    node_fs_1.default.mkdirSync(logDir);
}
const logger = winston_1.default.createLogger({
    level: 'info',
    format: winston_2.format.combine(winston_2.format.timestamp({
        format: 'YYYY-MM-DD HH:mm:ss'
    }), winston_2.format.errors({ stack: true }), winston_2.format.splat(), winston_2.format.json()),
    defaultMeta: { service: 'coinspot-api-v2' },
    transports: [
        new winston_1.default.transports.File({ filename: node_path_1.default.join(logDir, 'error.log'), level: 'error' }),
        new winston_1.default.transports.File({ filename: node_path_1.default.join(logDir, 'combined.log') })
    ]
});
if (process.env['NODE_ENV'] !== 'production') {
    logger.add(new winston_1.default.transports.Console({
        format: winston_2.format.combine(winston_2.format.colorize(), winston_2.format.simple())
    }));
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function logApiCall(functionName, params, result) {
    logger.info(`API Call: ${functionName}`, {
        params: JSON.stringify(params, null, 2),
        result: JSON.stringify(result, null, 2)
    });
}
exports.default = logger;
//# sourceMappingURL=logger.js.map